@@ -5,28 +5,26 @@ Async interface using asyncpg
 
 import logging
 import re
-from collections import OrderedDict
-from collections import defaultdict
+from collections import OrderedDict, defaultdict
 from random import randrange
 
 import asyncpg
-import ujson
-
 import pandas as pd
 
+import ujson
 from firepit import get_storage, pgstorage
 from firepit.deref import auto_deref
-from firepit.exceptions import InvalidAttr, InvalidObject, InvalidStixPath, UnknownViewname
-from firepit.pgstorage import (CHECK_FOR_QUERIES_TABLE,
-                               CHECK_FOR_COMMON_SCHEMA,
-                               INTERNAL_TABLES, LIKE_BIN, MATCH_BIN,
-                               MATCH_FUN, SUBNET_FUN, _rewrite_view_def)
-from firepit.props import auto_agg_tuple, parse_prop, prop_metadata
-from firepit.query import (Aggregation, BinnedColumn, Column, Filter, Group,
-                           Join, Limit, Offset, Order, Predicate, Projection,
-                           Query, Table)
+from firepit.exceptions import InvalidAttr, InvalidStixPath, UnknownViewname
+from firepit.pgstorage import (CHECK_FOR_COMMON_SCHEMA,
+                               CHECK_FOR_QUERIES_TABLE, INTERNAL_TABLES,
+                               LIKE_BIN, MATCH_BIN, MATCH_FUN, SUBNET_FUN,
+                               _rewrite_view_def)
+from firepit.props import parse_prop, prop_metadata
+from firepit.query import Column, Limit, Offset, Order, Projection, Query
 from firepit.splitter import RecordList, shorten_extension_name
-from firepit.sqlstorage import DB_VERSION, _transform, get_path_joins, _get_col_dict, _format_query, _make_aggs, SqlStorage
+from firepit.sqlstorage import (DB_VERSION, SqlStorage, _format_query,
+                                _get_col_dict, _make_aggs, _transform,
+                                get_path_joins)
 from firepit.validate import validate_name, validate_path
 
 logger = logging.getLogger(__name__)
@@ -53,12 +51,12 @@ class AsyncStorage:
         self.session_id = session_id
         self.conn = None
 
-    async def create(self):
+    async def create(self, ssl_context=None):
         """
         Create a new "session" (PostgreSQL schema).  Fail if it already exists.
         """
         logger.debug('Creating storage for session %s', self.session_id)
-        self.conn = await asyncpg.connect(self.connstring)
+        self.conn = await asyncpg.connect(self.connstring, ssl=ssl_context)
 
         # common schema
         async with self.conn.transaction():
@@ -70,12 +68,13 @@ class AsyncStorage:
                 await self.conn.execute(LIKE_BIN)
                 await self.conn.execute(SUBNET_FUN)
 
+        await self.conn.execute(f'CREATE SCHEMA IF NOT EXISTS "{self.session_id}"')
         await self.conn.execute(f'SET search_path TO "{self.session_id}", firepit_common')
 
         async with self.conn.transaction():
-            await self.conn.execute(f'CREATE SCHEMA IF NOT EXISTS "{self.session_id}"')
             # create tables, etc.
             for stmt in INTERNAL_TABLES:
+                logger.debug('%s', stmt)
                 await self.conn.execute(stmt)
             # Record db version
             await self._set_meta('dbversion', DB_VERSION)
@@ -84,6 +83,7 @@ class AsyncStorage:
         """
         Attach/connect to an existing session.  Fail if it doesn't exist.
         """
+        logger.debug('Attaching to storage for session %s', self.session_id)
         self.conn = await asyncpg.connect(self.connstring)
         await self.conn.execute(f'SET search_path TO "{self.session_id}", firepit_common')
 
@@ -204,8 +204,9 @@ class AsyncStorage:
 
     async def fetch(self, query, *args):
         """Passthrough to underlying DB"""
-        n = len(args) if args is not None else 0
-        query = query % tuple(f'${i}' for i in range(1, n + 1))
+        if '%s' in query:
+            n = len(args) if args is not None else 0
+            query = query % tuple(f'${i}' for i in range(1, n + 1))
         try:
             result = await self.conn.fetch(query, *args)
         except asyncpg.exceptions.UndefinedColumnError as e:
@@ -382,9 +383,12 @@ class AsyncSplitWriter:
         self.query_id = query_id
 
     async def init(self):
-        session_id = self.query_id
+        session_id = self.writer.session_id
         conn = self.writer.conn
-        await conn.execute(f'CREATE SCHEMA IF NOT EXISTS "{session_id}"')
+        try:
+            await conn.execute(f'CREATE SCHEMA IF NOT EXISTS "{session_id}"')
+        except asyncpg.exceptions.UniqueViolationError:
+            pass  # Potential race condition?
         await conn.execute(f'SET search_path TO "{session_id}", firepit_common')
 
         stmt = CHECK_FOR_QUERIES_TABLE.replace('%s', '$1')  # HACK
@@ -403,21 +407,17 @@ class AsyncSplitWriter:
 
     async def _load_schema(self, obj_type):
         props = await self.writer.properties(obj_type)
-        return OrderedDict({col['name']: col['type'] for col in props})
+        schema = OrderedDict({col['name']: col['type'] for col in props})
+        logger.debug('Loaded "%s" schema (%d columns total)', obj_type, len(schema))
+        return schema
 
     async def _load_schemas(self):
-        cols = await self.writer.properies()
+        cols = await self.writer.properties()
         for col in cols:
             schema = self.schemas.get(col['table'], {})
             schema[col['name']] = col['type']
             self.schemas[col['table']] = schema
-        # TODO: is this necessary?
-        self.schemas['__columns'] = OrderedDict({
-            'otype': 'TEXT',
-            'path': 'TEXT',
-            'shortname': 'TEXT',
-            'dtype': 'TEXT',
-        })
+        logger.debug("Loaded %d schemas (%d columns total)", len(self.schemas), len(cols))
 
     async def write(self, obj):
         """Consume `obj` (actual writing to storage may be deferred)"""
@@ -463,9 +463,11 @@ class AsyncSplitWriter:
             self.schemas[obj_type] = schema
             try:
                 await self.writer.new_type(obj_type, schema)
+                logger.debug('Added new type %s', obj_type)
             except (asyncpg.exceptions.DuplicateTableError,
                     asyncpg.exceptions.UniqueViolationError,
-                    asyncpg.exceptions.DuplicateObjectError):
+                    asyncpg.exceptions.DuplicateObjectError) as e:
+                logger.error('TEMP: %s', e)
                 logger.debug('Failed to add %s; refreshing schemas', obj_type)
                 # Refresh schemas
                 loaded_schema = await self._load_schema(obj_type)
@@ -698,13 +700,20 @@ class AsyncSqlWriter:
                       if not i['table_name'].startswith('_')]
         return tables
 
-    async def properties(self, obj_type):
-        tablename = f'{self.prefix}{obj_type}'
-        stmt = ("SELECT column_name AS name, data_type AS type"
-                " FROM information_schema.columns"
-                " WHERE table_schema = $1"
-                " AND table_name = $2")
-        rows = await self.conn.fetch(stmt, self.session_id, tablename)
+    async def properties(self, obj_type=None):
+        if obj_type:
+            tablename = f'{self.prefix}{obj_type}'
+            stmt = ("SELECT column_name AS name, data_type AS type"
+                    " FROM information_schema.columns"
+                    " WHERE table_schema = $1"
+                    " AND table_name = $2")
+            rows = await self.conn.fetch(stmt, self.session_id, tablename)
+            logger.debug('Schema "%s" rows: %s', tablename, rows)
+        else:
+            stmt = ("SELECT table_name AS table, column_name AS name, data_type AS type"
+                    " FROM information_schema.columns"
+                    " WHERE table_schema = $1")
+            rows = await self.conn.fetch(stmt, self.session_id)
         return [dict(row) for row in rows]
 
 
@@ -878,7 +887,7 @@ class SyncWrapper(AsyncStorage):
             self.placeholder = '?'
             self.dialect = 'sqlite3'
 
-    async def create(self):
+    async def create(self, ssl_context=None):
         """
         Create a new "session" (SQLite3 file).  Fail if it already exists.
         """
@@ -924,7 +933,7 @@ class SyncWrapper(AsyncStorage):
         """Get the column names (properties) of `viewname`"""
         return self.store.columns(viewname)
 
-    async def schema(self, viewname):
+    async def schema(self, viewname=None):
         """Get the schema (names and types) of `viewname`"""
         return self.store.schema(viewname)
 
