@@ -52,8 +52,7 @@ def _transform(filename):
         if 'type' not in obj:
             obj['type'], _, _ = obj['id'].rpartition('--')
         if obj['type'] != 'identity':
-            for o in (raft.json_normalize(obj, flat_lists=False)
-                      for obj in raft.flatten(obj)):
+            for o in raft.flatten(obj):
                 yield o
         else:
             yield obj
@@ -343,7 +342,7 @@ class SqlStorage:
         validate_name(viewname)
         validate_name(tablename)
         try:
-            where = stix2sql(pattern, sco_type) if pattern else None
+            where = stix2sql(pattern, sco_type, self.dialect) if pattern else None
         except Exception as e:
             logger.error('%s', e)
             raise StixPatternError(pattern) from e
@@ -589,7 +588,7 @@ class SqlStorage:
                      sco_type, viewname, input_view, pattern)
         slct = self._get_view_def(input_view)
         try:
-            where = stix2sql(pattern, sco_type) if pattern else None
+            where = stix2sql(pattern, sco_type, self.dialect) if pattern else None
         except Exception as e:
             logger.error('%s', e)
             raise StixPatternError(pattern) from e
